# cnest

An efficient library providing operators on Python's nested data structures. It includes C++ implementation of several key nest functions that are performance critical.

This library is developed by [Haonan Yu](https://github.com/hnyu) and alf contributors.
